@@ -12,6 +12,23 @@ CORBA_ORB CORBA_ORB_init (int                *argc,
 			  CORBA_ORBid         orb_identifier,
 			  CORBA_Environment  *ev);
 
+#ifdef ORBIT2_EXTENSIONS
+
+/* Will return TRUE if the named protocol is supported by 
+ * the ORB. Currently supported values of "name" are:
+ *
+ *    "IPv4"
+ *    "IPv6"
+ *    "UNIX"
+ *    "IrDA"
+ *    "SSL"
+ * 
+ * Unknown or unsupported values of "name" will make this 
+ * method return FALSE.*/
+gboolean  ORBit_proto_use (const char *name);
+
+#endif /* ORBIT2_EXTENSIONS */
+
 #ifdef ORBIT2_INTERNAL_API
 
 void      ORBit_ORB_forw_bind (CORBA_ORB                   orb,
