@@ -167,11 +167,11 @@ get_netid(LinkNetIdType which,
 
  		for (i = 0; i < num; i++) {
 			adr = (struct sockaddr_in *)&my_ifreqs[i].ifr_ifru.ifru_addr;
-			if (strcmp("127.0.0.1", inet_ntoa((struct in_addr)adr->sin_addr)))
+			if (strcmp("127.0.0.1", inet_ntoa(adr->sin_addr)))
 				break;
 		}
-		// will be 127.0.0.1 anyway, if no other address is defined...
-		return strncpy(buf, (const char*)inet_ntoa((struct in_addr)adr->sin_addr), len);
+		/* will be 127.0.0.1 anyway, if no other address is defined... */
+		return strncpy(buf, (const char*)inet_ntoa(adr->sin_addr), len);
 #else
 		SOCKET sock;
 		DWORD nbytes;
@@ -236,6 +236,7 @@ get_netid(LinkNetIdType which,
 	}
 
 	if (LINK_NET_ID_IS_FQDN == which) {
+#ifdef HAVE_GETADDRINFO
 		struct addrinfo *result, hints;
 		memset(&hints, 0, sizeof(struct addrinfo));
 		hints.ai_flags = AI_CANONNAME;
@@ -244,7 +245,17 @@ get_netid(LinkNetIdType which,
 			freeaddrinfo(result);
 		} else
 			goto out;
+#else
+		struct hostent *he;
 
+		/* gethostbyname() is MT-safe on Windows, btw */
+		he = gethostbyname(buf);
+
+		if (!he)
+		  goto out;
+
+		strncpy(buf, he->h_name, len);
+#endif
 		return buf;
 	}
 
