@@ -1,17 +1,21 @@
 #include <config.h>
 #include <stdio.h>
 #include <fcntl.h>
-#include <unistd.h>
-#include <dirent.h>
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <string.h>
-#include <utime.h>
+#ifdef HAVE_UTIME_H
+#  include <utime.h>
+#endif
 
 #include "giop-private.h"
 #include "giop-debug.h"
 #include <orbit/util/orbit-genrand.h>
+#include <glib/gstdio.h>
 
 /* FIXME: need to clean this up at shutdown */
 static int      corba_wakeup_fds[2];
@@ -38,12 +42,12 @@ test_safe_socket_dir (const char *dirname)
 {
 	struct stat statbuf;
 
-	if (stat (dirname, &statbuf) != 0) {
+	if (g_stat (dirname, &statbuf) != 0) {
 		S_PRINT (("Can not stat %s\n", dirname));
 		return FALSE;
 	}
 	
-#ifndef __CYGWIN__
+#ifndef G_PLATFORM_WIN32
 	if (statbuf.st_uid != getuid ()) {
 		S_PRINT (("Owner of %s is not the current user\n", dirname));
 		return FALSE;
@@ -69,28 +73,28 @@ scan_socket_dir (const char *dir, const char *prefix)
 {
 	int prefix_len;
 	char *cur_dir = NULL;
-	DIR   *dirh;
-	struct dirent *dent;
+	GDir   *dirh;
+	const char *dent;
 
 	g_return_val_if_fail (dir != NULL, NULL);
 	g_return_val_if_fail (prefix != NULL, NULL);
 	
-	dirh = opendir (dir);
+	dirh = g_dir_open (dir, 0, NULL);
 	if (!dirh)
 		return NULL;
 	prefix_len = strlen (prefix);
 
-	while ((dent = readdir (dirh))) {
+	while ((dent = g_dir_read_name (dirh))) {
 		char *name;
 
-		if (strncmp (dent->d_name, prefix, prefix_len))
+		if (strncmp (dent, prefix, prefix_len))
 			continue;
 
-		name = g_strconcat (dir, "/", dent->d_name, NULL);
+		name = g_build_filename (dir, dent, NULL);
 
 		/* Check it's credentials */
 		if (!test_safe_socket_dir (name)) {
-			dprintf (GIOP, "DOS attack with '%s'", name);
+			dprintf (GIOP, "DOS attack with '%s'\n", name);
 			g_free (name);
 			continue;
 		}
@@ -102,7 +106,7 @@ scan_socket_dir (const char *dir, const char *prefix)
 		} else
 			g_free (name);
 	}
-	closedir (dirh);
+	g_dir_close (dirh);
 
 	return cur_dir;
 }
@@ -128,13 +132,13 @@ giop_tmpdir_init (void)
 
 		safe_dir = scan_socket_dir (tmp_root, dirname);
 		if (safe_dir) {
-			dprintf (GIOP, "Have safe dir '%s'", safe_dir);
+			dprintf (GIOP, "Have safe dir '%s'\n", safe_dir);
 			link_set_tmpdir (safe_dir);
 			break;
 		}
 
 		if (iteration == 0)
-			newname = g_strconcat (tmp_root, "/", dirname, NULL);
+			newname = g_build_filename (tmp_root, dirname, NULL);
 		else {
 			struct {
 				guint32 a;
@@ -145,10 +149,11 @@ giop_tmpdir_init (void)
 					     ORBIT_GENUID_OBJECT_ID);
 
 			newname = g_strdup_printf (
-				"%s/%s-%4x", tmp_root, dirname, id.b);
+				"%s" G_DIR_SEPARATOR_S "%s-%4x",
+				tmp_root, dirname, id.b);
 		}
 
-		if (mkdir (newname, 0700) < 0) {
+		if (g_mkdir (newname, 0700) < 0) {
 			switch (errno) {
 			case EACCES:
 				g_error ("I can't write to '%s', ORB init failed",
@@ -156,12 +161,14 @@ giop_tmpdir_init (void)
 				break;
 				
 			case ENAMETOOLONG:
-				g_error ("Name '%s' too long your unix is broken",
+				g_error ("Name '%s' too long your system is broken",
 					 newname);
 				break;
 
 			case ENOMEM:
+#ifdef ELOOP
 			case ELOOP:
+#endif
 			case ENOSPC:
 			case ENOTDIR:
 			case ENOENT:
@@ -172,13 +179,15 @@ giop_tmpdir_init (void)
 				break;
 			}
 		}
+#if defined (HAVE_UTIME_H) && !defined (G_OS_WIN32)
+		/* This seems pretty useless, forget it on Win32 */
 
 		{ /* Hide some information ( apparently ) */
 			struct utimbuf utb;
 			memset (&utb, 0, sizeof (utb));
 			utime (newname, &utb);
 		}
-		
+#endif		
 		/* Possible race - so we re-scan. */
 
 		iteration++;
@@ -404,9 +413,9 @@ giop_thread_request_push_key (gpointer  key,
 		tdata = new_tdata;
 		if (key)
 			giop_thread_key_add_T (tdata, key);
-		dprintf (GIOP, "Create new thread %p for op", tdata);
+		dprintf (GIOP, "Create new thread %p for op\n", tdata);
 	} else
-		dprintf (GIOP, "Re-use thread %p for op", tdata);
+		dprintf (GIOP, "Re-use thread %p for op\n", tdata);
 
 	giop_thread_request_push (tdata, poa_object, recv_buffer);
 
@@ -442,7 +451,11 @@ giop_mainloop_handle_input (GIOChannel     *source,
 	char c;
 	GIOPThread *tdata = giop_thread_self ();
 
+#ifdef HAVE_WINSOCK2_H
+	recv (WAKEUP_POLL, &c, sizeof (c), 0);
+#else
 	read (WAKEUP_POLL, &c, sizeof (c));
+#endif
 
 	LINK_MUTEX_LOCK (tdata->lock);
 	while (!giop_thread_queue_empty_T (tdata)) {
@@ -465,7 +478,7 @@ giop_request_handler_thread (gpointer data, gpointer user_data)
 
 	g_private_set (giop_tdata_private, tdata);
 
-	dprintf (GIOP, "Thread %p woken to handle request", tdata);
+	dprintf (GIOP, "Thread %p woken to handle request\n", tdata);
 
 	do {
 		giop_thread_queue_process (tdata);
@@ -485,7 +498,7 @@ giop_request_handler_thread (gpointer data, gpointer user_data)
 
 	} while (!done);
 
-	dprintf (GIOP, "Thread %p returning to pool", tdata);
+	dprintf (GIOP, "Thread %p returning to pool\n", tdata);
 
 	giop_thread_free (tdata);
 	g_private_set (giop_tdata_private, NULL);
@@ -513,10 +526,17 @@ giop_init (gboolean thread_safe, gboolean blank_wire_data)
 		giop_main_thread = tdata = giop_thread_new (
 			g_main_context_default ()); /* main thread */
 
-		if (pipe (corba_wakeup_fds) < 0) /* cf. g_main_context_init_pipe */
+		if (link_pipe (corba_wakeup_fds) < 0) /* cf. g_main_context_init_pipe */
 			g_error ("Can't create CORBA main-thread wakeup pipe");
-		fcntl (WAKEUP_WRITE, F_SETFL, O_NONBLOCK);
 
+#ifdef HAVE_WINSOCK2_H
+		{
+			u_long yes = 1;
+			ioctlsocket (WAKEUP_WRITE, FIONBIO, &yes);
+		}
+#else
+		fcntl (WAKEUP_WRITE, F_SETFL, O_NONBLOCK);
+#endif
 		giop_main_source = link_source_create_watch (
 			g_main_context_default (), WAKEUP_POLL,
 			NULL, (G_IO_IN | G_IO_PRI),
@@ -542,8 +562,15 @@ wakeup_mainloop (void)
 {
 	char c = 'A'; /* magic */
 	int  res;
+#ifdef HAVE_WINSOCK2_H
+	if ((res = send (WAKEUP_WRITE, &c, sizeof (c), 0)) == SOCKET_ERROR) {
+		res = -1;
+		link_map_winsock_error_to_errno ();
+	}
+#else
 	while ((res = write (WAKEUP_WRITE, &c, sizeof (c))) < 0  &&
 	       errno == EINTR );
+#endif
 	if (res < 0 && errno == EAGAIN)
 		return;
 	if (res < 0)
@@ -566,7 +593,7 @@ giop_invoke_async (GIOPMessageQueueEntry *ent)
 {
 	GIOPRecvBuffer *buf = ent->buffer;
 
-	dprintf (GIOP, "About to invoke %p:%p (%d) (%p:%p)",
+	dprintf (GIOP, "About to invoke %p:%p (%d) (%p:%p)\n",
 		 ent, ent->async_cb, giop_thread_io(),
 		 ent->src_thread, giop_main_thread);
 
@@ -598,7 +625,6 @@ void
 giop_main_run (void)
 {
 	if (giop_thread_io ()) {
-		g_assert (giop_thread_self () == giop_main_thread);
 		g_assert (giop_main_loop == NULL);
 		giop_main_loop = g_main_loop_new (NULL, TRUE);
 		g_main_loop_run (giop_main_loop);
@@ -626,8 +652,13 @@ giop_shutdown (void)
 		}
 
 		if (WAKEUP_WRITE >= 0) {
+#ifdef HAVE_WINSOCK2_H
+			closesocket (WAKEUP_WRITE);
+			closesocket (WAKEUP_POLL);
+#else
 			close (WAKEUP_WRITE);
 			close (WAKEUP_POLL);
+#endif
 			WAKEUP_WRITE = -1;
 			WAKEUP_POLL = -1;
 		}
